@@ -23,9 +23,32 @@ fi
 # detect unset variables
 set -u
 
+if ! which clang++$CLANGSUFFIX >/dev/null 2>&1 ; then
+  echo "could not find clang++$CLANGSUFFIX"
+  exit 1
+fi
+
+# find out how to build fuzzer. On amd64 and arm64, libFuzzer is built with the compiler and activated
+# with -fsanitize=fuzzer at link time. On power, libFuzzer is shipped separately.
+testfuzzer=testfuzzer.cpp
+/bin/echo -e "#include <cstddef>\n#include <cstdint>\nextern \"C\" int LLVMFuzzerTestOneInput(const uint8_t *Data, size_t Size) {return 0;}" >$testfuzzer
+if clang++$CLANGSUFFIX -o testfuzzer $testfuzzer -fsanitize=fuzzer && ./testfuzzer -runs=1 >/dev/null 2>&1 ; then
+   echo "will use -fsanitize=fuzzer to link libFuzzer"
+   SIMDJSON_FUZZ_LDFLAGS="-fsanitize=fuzzer"
+elif clang++$CLANGSUFFIX -o testfuzzer $testfuzzer -fsanitize=fuzzer-no-link -lFuzzer  && ./testfuzzer -runs=1 >/dev/null 2>&1 ; then
+   echo "will use -lFuzzer to link libFuzzer"
+   SIMDJSON_FUZZ_LDFLAGS="-lFuzzer"
+else
+  echo "could not link to the fuzzer with -fsanitize=fuzzer or -lFuzzer"
+  exit 1
+fi
+
+if [ -e testfuzzer ] ; then rm testfuzzer; fi
+if [ -e $testfuzzer ] ; then rm $testfuzzer; fi
+
 # common options
 CXX_CLAGS_COMMON=-DFUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION
-COMMON="-GNinja -DCMAKE_CXX_COMPILER=clang++$CLANGSUFFIX -DCMAKE_C_COMPILER=clang$CLANGSUFFIX -DSIMDJSON_BUILD_STATIC=Off -DENABLE_FUZZING=On -DSIMDJSON_COMPETITION=OFF -DSIMDJSON_GOOGLE_BENCHMARKS=OFF -DSIMDJSON_DISABLE_DEPRECATED_API=On"
+COMMON="-GNinja -DCMAKE_CXX_COMPILER=clang++$CLANGSUFFIX -DCMAKE_C_COMPILER=clang$CLANGSUFFIX -DSIMDJSON_DEVELOPER_MODE=ON -DBUILD_SHARED_LIBS=ON -DSIMDJSON_ENABLE_FUZZING=On -DSIMDJSON_COMPETITION=OFF -DSIMDJSON_GOOGLE_BENCHMARKS=OFF -DSIMDJSON_DISABLE_DEPRECATED_API=On -DSIMDJSON_FUZZ_LDFLAGS=$SIMDJSON_FUZZ_LDFLAGS"
 
 # A replay build, as plain as it gets. For use with valgrind/gdb.
 variant=replay
@@ -67,8 +90,7 @@ variant=sanitizers-O3
 	      -DCMAKE_CXX_FLAGS="-O3 -fsanitize=fuzzer-no-link,address,undefined -fno-sanitize-recover=undefined $CXX_CLAGS_COMMON" \
 	      -DCMAKE_C_FLAGS="-O3 -fsanitize=fuzzer-no-link,address,undefined -fno-sanitize-recover=undefined" \
 	      -DCMAKE_BUILD_TYPE=Debug \
-	      -DSIMDJSON_FUZZ_LINKMAIN=Off \
-	      -DSIMDJSON_FUZZ_LDFLAGS="-fsanitize=fuzzer"
+	      -DSIMDJSON_FUZZ_LINKMAIN=Off
 
 	ninja all_fuzzers
 	cd ..
@@ -85,8 +107,7 @@ variant=sanitizers-O0
 	      -DCMAKE_CXX_FLAGS="-O0 -fsanitize=fuzzer-no-link,address,undefined -fno-sanitize-recover=undefined $CXX_CLAGS_COMMON" \
 	      -DCMAKE_C_FLAGS="-O0 -fsanitize=fuzzer-no-link,address,undefined -fno-sanitize-recover=undefined" \
 	      -DCMAKE_BUILD_TYPE=Debug \
-	      -DSIMDJSON_FUZZ_LINKMAIN=Off \
-	      -DSIMDJSON_FUZZ_LDFLAGS="-fsanitize=fuzzer"
+	      -DSIMDJSON_FUZZ_LINKMAIN=Off
 
 	ninja all_fuzzers
 	cd ..
@@ -105,8 +126,7 @@ variant=fast
 	      -DCMAKE_CXX_FLAGS="-fsanitize=fuzzer-no-link $CXX_CLAGS_COMMON" \
 	      -DCMAKE_C_FLAGS="-fsanitize=fuzzer-no-link" \
 	      -DCMAKE_BUILD_TYPE=Release \
-	      -DSIMDJSON_FUZZ_LINKMAIN=Off \
-	      -DSIMDJSON_FUZZ_LDFLAGS="-fsanitize=fuzzer"
+	      -DSIMDJSON_FUZZ_LINKMAIN=Off
 
 	ninja all_fuzzers
 	cd ..
