@@ -1,15 +1,17 @@
-#include "simdjson/error.h"
+#ifndef SIMDJSON_GENERIC_ONDEMAND_PARSER_H
+
+#ifndef SIMDJSON_CONDITIONAL_INCLUDE
+#define SIMDJSON_GENERIC_ONDEMAND_PARSER_H
+#include "simdjson/generic/ondemand/base.h"
+#include "simdjson/generic/implementation_simdjson_result_base.h"
+#endif // SIMDJSON_CONDITIONAL_INCLUDE
+
+#include <memory>
 
 namespace simdjson {
 namespace SIMDJSON_IMPLEMENTATION {
 namespace ondemand {
 
-class array;
-class object;
-class value;
-class raw_json_string;
-class document_stream;
-
 /**
  * The default batch size for document_stream instances for this On Demand kernel.
  * Note that different On Demand kernel may use a different DEFAULT_BATCH_SIZE value
@@ -349,3 +351,5 @@ public:
 };
 
 } // namespace simdjson
+
+#endif // SIMDJSON_GENERIC_ONDEMAND_PARSER_H
\ No newline at end of file
