@@ -1,13 +1,9 @@
 #ifndef SIMDJSON_PADDED_STRING_VIEW_INL_H
 #define SIMDJSON_PADDED_STRING_VIEW_INL_H
 
-#include "simdjson/portability.h"
-#include "simdjson/common_defs.h" // for SIMDJSON_PADDING
+#include "simdjson/padded_string_view.h"
 
-#include <climits>
-#include <cstring>
-#include <memory>
-#include <string>
+#include "simdjson/error-inl.h"
 
 namespace simdjson {
 
@@ -35,6 +31,11 @@ inline size_t padded_string_view::capacity() const noexcept { return _capacity;
 
 inline size_t padded_string_view::padding() const noexcept { return capacity() - length(); }
 
+#if SIMDJSON_EXCEPTIONS
+inline std::ostream& operator<<(std::ostream& out, simdjson_result<padded_string_view> &s) noexcept(false) { return out << s.value(); }
+#endif
+
 } // namespace simdjson
 
+
 #endif // SIMDJSON_PADDED_STRING_VIEW_INL_H
