@@ -634,7 +634,7 @@ namespace document_stream_tests {
     ASSERT_SUCCESS( odparser.parse_many(json.data(), json.length(), 50).get(odstream) );
     for (auto doc: odstream) {
       if(counter < 6) {
-        int64_t val;
+        int64_t val{};
         ASSERT_SUCCESS(doc.at_pointer("/4").get(val));
         ASSERT_EQUAL(val, 5);
       } else {
@@ -797,7 +797,7 @@ namespace document_stream_tests {
       simdjson::dom::document_stream stream;
       ASSERT_SUCCESS( parser.parse_many(str, batch_size).get(stream) );
       for (auto doc : stream) {
-        int64_t keyid;
+        int64_t keyid{};
         ASSERT_SUCCESS( doc["id"].get(keyid) );
         ASSERT_EQUAL( keyid, int64_t(count) );
 
@@ -837,7 +837,7 @@ namespace document_stream_tests {
       simdjson::dom::document_stream stream;
       ASSERT_SUCCESS( parser.parse_many(str, batch_size).get(stream) );
       for (auto doc : stream) {
-        int64_t keyid;
+        int64_t keyid{};
         ASSERT_SUCCESS( doc["id"].get(keyid) );
         ASSERT_EQUAL( keyid, int64_t(count) );
 
