@@ -5,6 +5,79 @@ using namespace simdjson;
 
 namespace misc_tests {
   using namespace std;
+  bool issue1981_success() {
+    auto error_phrase = R"(false)"_padded;
+    TEST_START();
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(error_phrase).get(doc));
+    bool b;
+    ASSERT_SUCCESS( doc.get_bool().get(b));
+    ASSERT_FALSE(b);
+    TEST_SUCCEED();
+  }
+
+  bool issue1981_failure() {
+    auto error_phrase = R"(falseA)"_padded;
+    TEST_START();
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(error_phrase).get(doc));
+    bool b;
+    ASSERT_ERROR( doc.get_bool().get(b), INCORRECT_TYPE);
+    TEST_SUCCEED();
+  }
+
+  bool replacement_char() {
+    auto fun_phrase = R"( ["I \u2665 Unicode. Even broken \ud800 Unicode." ])"_padded;
+    std::string_view expected_fun = "I \xe2\x99\xa5 Unicode. Even broken \xef\xbf\xbd Unicode.";
+
+    TEST_START();
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(fun_phrase).get(doc));
+    ondemand::array arr;
+    ASSERT_SUCCESS( doc.get_array().get(arr));
+    std::string_view view;
+    ASSERT_SUCCESS( arr.at(0).get_string(true).get(view));
+    ASSERT_EQUAL(view, expected_fun);
+    TEST_SUCCEED();
+  }
+
+  bool wobbly_tests() {
+    auto lone_surrogate = R"( "\ud800" )"_padded;
+    std::string_view expected_lone = "\xed\xa0\x80";
+
+
+    auto fun_phrase = R"( ["I \u2665 Unicode. Even broken \ud800 Unicode." ])"_padded;
+    std::string_view expected_fun = "I \xe2\x99\xa5 Unicode. Even broken \xed\xa0\x80 Unicode.";
+
+    auto insane_url = R"({"input": "http://example.com/\uDC00\uD834\uDF06\uDC00"} )"_padded;
+    std::string_view expected_insane = "http://example.com/\xED\xB0\x80\xF0\x9D\x8C\x86\xED\xB0\x80";
+
+    TEST_START();
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(lone_surrogate).get(doc));
+    std::string_view view;
+    ASSERT_SUCCESS( doc.get_wobbly_string().get(view));
+    ASSERT_EQUAL(view, expected_lone);
+
+    ASSERT_SUCCESS(parser.iterate(fun_phrase).get(doc));
+    ondemand::array arr;
+    ASSERT_SUCCESS( doc.get_array().get(arr));
+    ASSERT_SUCCESS( arr.at(0).get_wobbly_string().get(view));
+    ASSERT_EQUAL(view, expected_fun);
+
+    ASSERT_SUCCESS(parser.iterate(insane_url).get(doc));
+    ondemand::object obj;
+    ASSERT_SUCCESS( doc.get_object().get(obj));
+    ASSERT_SUCCESS( obj["input"].get_wobbly_string().get(view));
+
+    ASSERT_EQUAL(view, expected_insane);
+    TEST_SUCCEED();
+  }
+
   bool test_get_value() {
     TEST_START();
     ondemand::parser parser;
@@ -17,7 +90,7 @@ namespace misc_tests {
     ASSERT_SUCCESS(val.get_object().get(obj));
     ondemand::array arr;
     ASSERT_SUCCESS(obj["a"].get_array().get(arr));
-    size_t count;
+     size_t count{};
     ASSERT_SUCCESS(arr.count_elements().get(count));
     ASSERT_EQUAL(3,count);
     TEST_SUCCEED();
@@ -52,6 +125,30 @@ namespace misc_tests {
     TEST_SUCCEED();
   }
 
+  bool issue_uffff() {
+    TEST_START();
+    ondemand::parser parser;
+    auto json = R"(   "wow:\uFFFF"   )"_padded;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    std::string_view view;
+    ASSERT_SUCCESS( doc.get_string().get(view));
+    ASSERT_EQUAL(view, "wow:\xef\xbf\xbf");
+    TEST_SUCCEED();
+  }
+
+  bool issue_backslash() {
+    TEST_START();
+    ondemand::parser parser;
+    auto json = R"(   "sc:\\./"   )"_padded;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    std::string_view view;
+    ASSERT_SUCCESS( doc.get_string().get(view));
+    ASSERT_EQUAL(view, "sc:\\./");
+    TEST_SUCCEED();
+  }
+
   bool issue1870() {
     TEST_START();
     ondemand::parser parser;
@@ -439,9 +536,9 @@ namespace misc_tests {
     return true;
   }
   simdjson_warn_unused bool test_raw_json_token(string_view json, string_view expected_token, int expected_start_index = 0) {
-    string title = "'";
+    string title("'");
     title.append(json.data(), json.length());
-    title += "'";
+    title += std::string("'");
     padded_string json_padded = json;
     SUBTEST(title, test_ondemand_doc(json_padded, [&](auto doc) {
       string_view token;
@@ -455,11 +552,11 @@ namespace misc_tests {
     // Test values
     auto json_in_hash = string(R"({"a":)");
     json_in_hash.append(json.data(), json.length());
-    json_in_hash += "}";
+    json_in_hash += std::string("}");
     json_padded = json_in_hash;
-    title = "'";
+    title = std::string("'");
     title.append(json_in_hash.data(), json_in_hash.length());
-    title += "'";
+    title += std::string("'");
     SUBTEST(title, test_ondemand_doc(json_padded, [&](auto doc) {
       string_view token;
       ASSERT_SUCCESS( doc["a"].raw_json_token().get(token) );
@@ -496,6 +593,12 @@ namespace misc_tests {
 
   bool run() {
     return
+           issue1981_success() &&
+           issue1981_failure() &&
+           replacement_char() &&
+           wobbly_tests() &&
+           issue_uffff() &&
+           issue_backslash() &&
            issue1870() &&
            issue1894() &&
            issue1894toolarge() &&
